@@ -65,7 +65,7 @@ def run():
 
         if list:
             from runtasks.lister import print_list
-            print_list(tasks)
+            print_list(tasks, verbose=verbose)
             return 1
 
         # Parse the task arguments.
@@ -82,7 +82,7 @@ def run():
         for (task, args) in parsed:
             if args == "help":
                 from runtasks.lister import print_doc
-                print_doc(task)
+                print_doc(task, verbose=True)
                 return 1
 
         originaldir = os.getcwd()
