@@ -77,7 +77,7 @@ def format_doc(task):
     return '\n'.join(lines)
 
 
-def print_list(tasks, *, verbose):
+def print_list(tasks, verbose=False):
     """
     Called when "--list" is passed on the command line.  Prints the list of available tasks.
     """
